# Define your custom views here or overwrite the default views. Default
# CRUD operations are generated by the ringo frameworkd.
import logging
from pyramid.view import view_config
from ringo.lib.helpers import get_action_routename
from ringo.views.base.read import rest_read
from ringo_news import News

log = logging.getLogger(__name__)


def get_news(request):
    """Returns a list of News items which are attached to the current
    user of the request. The news are sorted by the date of the news.
    Recent news comes before older news. News with the same date are
    ordered by their internal id in descendig order. If the user marks
    the news as read, the news willl get detached form the user and is
    not listed anymore."""

    # Custom sort function with will sort the new based on their date
    # and id.
    def compare(b, a):
        return cmp(a.date, b.date) or cmp(a.id, b.id)

    if not request.user:
        return []
    else:
        request.user.news.sort(compare)
        return request.user.news


def _mark_news_as_read(request, item):
    """Will mark the given news item as read for the current user of the
    request.

    :request: current request
    :item: news item
    :returns: news item

    """
    # A news item will be shown for all users in item.users. To make it
    # read we remove the entry of the current user from the item.users
    # list. PLEASE NOTE that simply removing the user from the list
    # using the "remove()" method on the item.users does not work as
    # expected so we need to rebuild the list of users here.
    users = [user for user in item.users if user.id != request.user.id]
    item.users = users
    return item


def read_callback(request, item):
    """Callback which is called right after the news item has been loaded.

    :request: current request
    :item: the news item
    :returns: news item

    """
    item = _mark_news_as_read(request, item)
    return item


@view_config(route_name=get_action_routename(News, 'markasread',
                                             prefix="rest"),
             renderer='json',
             request_method="PUT",
             permission='read')
def rest_markasread(request):
    return rest_read(request, callback=read_callback)
